searchData={"items":[{"type":"module","title":"NodeActivator","doc":"This module provides functionality to turn a non-distributed Erlang node into a distributed node.\nIt handles the entire process of node activation, including:\n\n* Ensuring the EPMD (Erlang Port Mapper Daemon) is running\n* Generating unique node names\n* Starting the distributed node\n* Providing proper error handling and logging","ref":"NodeActivator.html"},{"type":"module","title":"Features - NodeActivator","doc":"* Automatic EPMD activation\n* Unique node name generation with customizable prefixes\n* Idempotent operation (safe to call multiple times)\n* Comprehensive error handling\n* Detailed logging of node operations","ref":"NodeActivator.html#module-features"},{"type":"module","title":"Usage - NodeActivator","doc":"The main function `run/1` takes a prefix string and returns either:\n* `{:ok, node()}` - The node was successfully started or was already running\n* `{:error, reason}` - An error occurred during node activation","ref":"NodeActivator.html#module-usage"},{"type":"module","title":"Dependencies - NodeActivator","doc":"* `epmd_up` - For EPMD management\n* `get_host` - For hostname resolution","ref":"NodeActivator.html#module-dependencies"},{"type":"module","title":"Examples - NodeActivator","doc":"# Start a new distributed node with prefix \"myapp\"\n    {:ok, node_name} = NodeActivator.run(\"myapp\")\n    # => {:ok, :\"myapp_abc123@hostname\"}\n\n    # Safe to call multiple times\n    {:ok, same_node} = NodeActivator.run(\"myapp\")\n    # => {:ok, :\"myapp_abc123@hostname\"}","ref":"NodeActivator.html#module-examples"},{"type":"function","title":"NodeActivator.run/1","doc":"Turns a non-distributed node into a distributed node after ensuring\nthat the `epmd` operation system process is running. Returns the name of the\nstarted distributed node. The node name will be generated by appending\na random string to the provided `node_name_prefix` string.\n\nThis function does nothing when the distribution has already\nbeen started.\n\nFor more info, see `Node`.","ref":"NodeActivator.html#run/1"},{"type":"function","title":"Examples - NodeActivator.run/1","doc":"{:ok, node_name} = NodeActivator.run(\"foo\")","ref":"NodeActivator.html#run/1-examples"},{"type":"module","title":"NodeActivator.Util","doc":"Utility functions for NodeActivator, providing helper functions for node management\nand name generation in distributed Erlang systems.","ref":"NodeActivator.Util.html"},{"type":"function","title":"NodeActivator.Util.generate_node_name/1","doc":"Generates a unique node name by combining a prefix with a random string and the hostname.","ref":"NodeActivator.Util.html#generate_node_name/1"},{"type":"function","title":"Parameters - NodeActivator.Util.generate_node_name/1","doc":"* `prefix` - A binary string that will be used as the prefix for the node name.\n    Spaces in the prefix will be replaced with hyphens.","ref":"NodeActivator.Util.html#generate_node_name/1-parameters"},{"type":"function","title":"Returns - NodeActivator.Util.generate_node_name/1","doc":"* `{:ok, atom()}` - A tuple containing the generated node name as an atom.\n  * `{:error, binary()}` - A tuple containing an error message if the hostname cannot be determined.","ref":"NodeActivator.Util.html#generate_node_name/1-returns"},{"type":"function","title":"Examples - NodeActivator.Util.generate_node_name/1","doc":"iex> {:ok, node_name} = NodeActivator.Util.generate_node_name(\"test\")\n    iex> is_atom(node_name)\n    true\n    iex> Atom.to_string(node_name) =~ ~r/test_[a-z2-7]+@.+/\n    true","ref":"NodeActivator.Util.html#generate_node_name/1-examples"},{"type":"extras","title":"NodeActivator","doc":"# NodeActivator\n\nA module to activate VM nodes.\n\nThis module provides functionality to turn a non-distributed Erlang node into a distributed node.\nIt handles the entire process of node activation, including:\n\n* Ensuring the EPMD (Erlang Port Mapper Daemon) is running\n* Generating unique node names\n* Starting the distributed node\n* Providing proper error handling and logging","ref":"readme.html"},{"type":"extras","title":"Features - NodeActivator","doc":"* Automatic EPMD activation\n* Unique node name generation with customizable prefixes\n* Idempotent operation (safe to call multiple times)\n* Comprehensive error handling\n* Detailed logging of node operations","ref":"readme.html#features"},{"type":"extras","title":"Usage - NodeActivator","doc":"The main function `run/1` takes a prefix string and returns either:\n* `{:ok, node()}` - The node was successfully started or was already running\n* `{:error, reason}` - An error occurred during node activation","ref":"readme.html#usage"},{"type":"extras","title":"Dependencies - NodeActivator","doc":"* `epmd_up` - For EPMD management\n* `get_host` - For hostname resolution","ref":"readme.html#dependencies"},{"type":"extras","title":"Examples - NodeActivator","doc":"# Start a new distributed node with prefix \"myapp\"\n    {:ok, node_name} = NodeActivator.run(\"myapp\")\n    # => {:ok, :\"myapp_abc123@hostname\"}\n\n    # Safe to call multiple times\n    {:ok, same_node} = NodeActivator.run(\"myapp\")\n    # => {:ok, :\"myapp_abc123@hostname\"}","ref":"readme.html#examples"},{"type":"extras","title":"Installation - NodeActivator","doc":"The package can be installed by adding `node_activator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:node_activator, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Tested Platforms - NodeActivator","doc":"* Ubuntu 22.04 / Elixir 1.18 / OTP 27\n* Ubuntu 22.04 / Elixir 1.17 / OTP 27\n* Ubuntu 22.04 / Elixir 1.16 / OTP 26\n* Ubuntu 22.04 / Elixir 1.15 / OTP 25\n* Windows 2022 / Elixir 1.18 / OTP 27\n* Windows 2019 / Elixir 1.18 / OTP 27","ref":"readme.html#tested-platforms"},{"type":"extras","title":"License - NodeActivator","doc":"Copyright (c) 2025 University of Kitakyushu\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}